Module oqtant.util.server
=========================

Classes
-------

`ThreadServer(config: uvicorn.config.Config)`
:

    ### Ancestors (in MRO)

    * uvicorn.server.Server

    ### Methods

    `install_signal_handlers(self) ‑> None`
    :

    `run_in_thread(self)`
    :
